Check that all exported functions are listed in pkgdown reference
Source:R/40_check_pkgdown_reference.R
check_pkgdown_reference.RdParses the NAMESPACE and _pkgdown.yml (if present) and reports any
exported functions that are missing from the pkgdown reference index.
Value
Invisibly returns a character vector of missing function names,
or NULL if _pkgdown.yml does not exist. Prints a summary via cli.
Examples
if (FALSE) { # \dontrun{
dir <- tempdir()
usethis::create_package(dir)
usethis::proj_set(dir)
usethis::use_pkgdown()
check_pkgdown_reference(dir)
} # }