Inquire Standalone Files from a GitHub Repository
Source:R/20_inquire_standalone.R
inquire_standalone.RdRetrieve information about all standalone R files in the R/ directory of a GitHub repository. Standalone files are identified by the "standalone-" prefix in their filename.
Value
A tibble with three columns:
owner/repoCharacter string, the repository identifier in "owner/repo" format.
- description
Character string, the description extracted from the file's YAML header or roxygen documentation.
- usage
Character string, the code to import the standalone file using
usethis::use_standalone().