Reference a permissively-licensed R package from GitHub for inclusion in your own R package. This function:
Creates
inst/vendor/pkg/with LICENSE files and a READMECreates
R/vendor-pkg.Rwith attribution header and optional vendored codeUpdates
DESCRIPTION(Authors@RandCopyrightfields)Prints an acknowledgement snippet for your README
Arguments
- pkg
GitHub repository specification in
"owner/repo"form or a full GitHub URL (e.g."https://github.com/owner/repo").- ...
File paths within the vendor package to copy into your package and append to the vendor R file. If empty (default), only the infrastructure is set up.
- branch
Github repository branch name. Defaults to
"main"- path
Path to the target package directory. If
NULL(the default), uses the current working directory.